==> Microsoft-AdCenter-6.01.tar.gz: Microsoft-AdCenter-6.01/lib/Microsoft/AdCenter/NotificationManagementService/GetArchivedNotificationsResponse.pm <==
package Microsoft::AdCenter::NotificationManagementService::GetArchivedNotificationsResponse;
# Copyright (C) 2010 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::ComplexType/;

=head1 NAME

Microsoft::AdCenter::NotificationManagementService::GetArchivedNotificationsResponse - Represents "GetArchivedNotificationsResponse" in Microsoft AdCenter Notification Management Service.

=cut

sub _type_name {
    return 'GetArchivedNotificationsResponse';
}

sub _namespace_uri {
    return 'http://adcenter.microsoft.com/syncapis';
}

our @_attributes = (qw/
    GetArchivedNotificationsResult
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    GetArchivedNotificationsResult => 'ArrayOfNotification',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 GetArchivedNotificationsResult

Gets/sets GetArchivedNotificationsResult (ArrayOfNotification)

=cut

==> Microsoft-AdCenter-7.02.tar.gz: Microsoft-AdCenter-7.02/lib/Microsoft/AdCenter/NotificationManagementService/GetArchivedNotificationsResponse.pm <==
package Microsoft::AdCenter::NotificationManagementService::GetArchivedNotificationsResponse;
# Copyright (C) 2010 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::ComplexType/;

=head1 NAME

Microsoft::AdCenter::NotificationManagementService::GetArchivedNotificationsResponse - Represents "GetArchivedNotificationsResponse" in Microsoft AdCenter Notification Management Service.

=cut

sub _type_name {
    return 'GetArchivedNotificationsResponse';
}

sub _namespace_uri {
    return 'http://adcenter.microsoft.com/syncapis';
}

our @_attributes = (qw/
    GetArchivedNotificationsResult
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    GetArchivedNotificationsResult => 'ArrayOfNotification',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 GetArchivedNotificationsResult

Gets/sets GetArchivedNotificationsResult (ArrayOfNotification)

=cut
